aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/room_send.h
diff options
context:
space:
mode:
authorn-peugnet <n.peugnet@free.fr>2022-10-06 19:27:24 +0200
committern-peugnet <n.peugnet@free.fr>2022-10-06 19:27:24 +0200
commit08632625e1a04257b5c7d4a9db2246ac07436748 (patch)
tree9ddadf219a7e352ddd3549ad1683282c944adfb6 /lib/csapi/room_send.h
parente9c2e2a26d3711e755aa5eb8a8478917c71d612b (diff)
parentd911b207f49e936b3e992200796110f0749ed150 (diff)
downloadlibquotient-08632625e1a04257b5c7d4a9db2246ac07436748.tar.gz
libquotient-08632625e1a04257b5c7d4a9db2246ac07436748.zip
Update upstream source from tag 'upstream/0.7.0'
Update to upstream version '0.7.0' with Debian dir 30dcb77a77433e4a54eab77c0b82ae925dead2d8
Diffstat (limited to 'lib/csapi/room_send.h')
-rw-r--r--lib/csapi/room_send.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/lib/csapi/room_send.h b/lib/csapi/room_send.h
index 96f5beca..abe5f207 100644
--- a/lib/csapi/room_send.h
+++ b/lib/csapi/room_send.h
@@ -16,9 +16,10 @@ namespace Quotient {
*
* The body of the request should be the content object of the event; the
* fields in this object will vary depending on the type of event. See
- * [Room Events](/client-server-api/#room-events) for the m. event specification.
+ * [Room Events](/client-server-api/#room-events) for the m. event
+ * specification.
*/
-class SendMessageJob : public BaseJob {
+class QUOTIENT_API SendMessageJob : public BaseJob {
public:
/*! \brief Send a message event to the given room.
*
@@ -29,9 +30,10 @@ public:
* The type of event to send.
*
* \param txnId
* The transaction ID for this event. Clients should generate an
* ID unique across requests with the same access token; it will be
* used by the server to ensure idempotency of requests.
*
* \param body
* This endpoint is used to send a message event to a room. Message events
@@ -29,9 +30,10 @@ public:
*
* \param txnId
- * The transaction ID for this event. Clients should generate an
- * ID unique across requests with the same access token; it will be
- * used by the server to ensure idempotency of requests.
+ * The [transaction ID](/client-server-api/#transaction-identifiers) for
+ * this event. Clients should generate an ID unique across requests with the
+ * same access token; it will be used by the server to ensure idempotency of
+ * requests.
*
* \param body